[LON-CAPA-cvs] cvs: loncom /auth loncacc.pm /interface domainprefs.pm loncommon.pm loncreateuser.pm lonhtmlcommon.pm lonmeta.pm lonprintout.pm lonsource.pm mydesk.tab

raeburn raeburn at source.lon-capa.org
Tue Jun 4 19:12:13 EDT 2013


raeburn		Tue Jun  4 23:12:13 2013 EDT

  Modified files:              
    /loncom/interface	domainprefs.pm loncommon.pm loncreateuser.pm 
                     	lonhtmlcommon.pm lonmeta.pm lonprintout.pm 
                     	lonsource.pm mydesk.tab 
    /loncom/auth	loncacc.pm 
  Log:
  - Replace terms: "Construction Space" with "Authoring Space"
    and: "Construction space" with "Authoring space"
    for consistency with type of role used to access it, and action taken there.
  
  
-------------- next part --------------
Index: loncom/interface/domainprefs.pm
diff -u loncom/interface/domainprefs.pm:1.195 loncom/interface/domainprefs.pm:1.196
--- loncom/interface/domainprefs.pm:1.195	Thu Apr 11 14:59:48 2013
+++ loncom/interface/domainprefs.pm	Tue Jun  4 23:12:08 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: domainprefs.pm,v 1.195 2013/04/11 14:59:48 bisitz Exp $
+# $Id: domainprefs.pm,v 1.196 2013/06/04 23:12:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -5461,7 +5461,7 @@
         my $source = $filepath.'/'.$file;
         my $logfile;
         if (!open($logfile,">>$source".'.log')) {
-            return (&mt('No write permission to Construction Space'));
+            return (&mt('No write permission to Authoring Space'));
         }
         print $logfile
 "\n================= Publish ".localtime()." ================\n".
Index: loncom/interface/loncommon.pm
diff -u loncom/interface/loncommon.pm:1.1131 loncom/interface/loncommon.pm:1.1132
--- loncom/interface/loncommon.pm:1.1131	Sun May 26 22:00:24 2013
+++ loncom/interface/loncommon.pm	Tue Jun  4 23:12:08 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common routines
 #
-# $Id: loncommon.pm,v 1.1131 2013/05/26 22:00:24 raeburn Exp $
+# $Id: loncommon.pm,v 1.1132 2013/06/04 23:12:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -4932,7 +4932,7 @@
 
 Inputs: $url (usually will be undef).
 
-Returns: Path to Construction Space containing the resource or 
+Returns: Path to Authoring Space containing the resource or 
          directory being viewed (or for which action is being taken). 
          If $url is provided, and begins /priv/<domain>/<uname>
          the path will be that portion of the $context argument.
@@ -4995,7 +4995,7 @@
        is appropriate for use in building the breadcrumb trail.
 
 Returns: HTML div with CSTR path and recent box
-         To be included on Construction Space pages
+         To be included on Authoring Space pages
 
 =cut
 
@@ -5026,7 +5026,7 @@
     my $output =
          '<div>'
         .&Apache::loncommon::help_open_menu('','',3,'Authoring') #FIXME: Broken? Where is it?
-        .'<b>'.&mt('Construction Space:').'</b> '
+        .'<b>'.&mt('Authoring Space:').'</b> '
         .'<form name="dirs" method="post" action="'.$formaction
         .'" target="_top">' #FIXME lonpubdir: target="_parent"
         .&Apache::lonhtmlcommon::crumbs($uname.'/'.$parentpath,'_top','/priv/'.$udom,undef,undef);
Index: loncom/interface/loncreateuser.pm
diff -u loncom/interface/loncreateuser.pm:1.376 loncom/interface/loncreateuser.pm:1.377
--- loncom/interface/loncreateuser.pm:1.376	Tue Apr  2 13:36:34 2013
+++ loncom/interface/loncreateuser.pm	Tue Jun  4 23:12:08 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Create a user
 #
-# $Id: loncreateuser.pm,v 1.376 2013/04/02 13:36:34 raeburn Exp $
+# $Id: loncreateuser.pm,v 1.377 2013/06/04 23:12:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1739,7 +1739,7 @@
                 }
             }
             if ($role_code eq 'ca' || $role_code eq 'au' || $role_code eq 'aa') {
-                $class='Construction Space';
+                $class='Authoring Space';
             } elsif ($role_code eq 'su') {
                 $class='System';
             } else {
@@ -1810,7 +1810,7 @@
 
     my $rolesdisplay = 0;
     my %output = ();
-    foreach my $type ('Construction Space','Course','Community','Domain','System','Unknown') {
+    foreach my $type ('Authoring Space','Course','Community','Domain','System','Unknown') {
         $output{$type} = '';
         foreach my $which (sort {uc($a) cmp uc($b)} (keys(%sortrole))) {
             if ( ($roleclass{$sortrole{$which}} =~ /^\Q$type\E/ ) && ($rolepriv{$sortrole{$which}}) ) {
@@ -1836,7 +1836,7 @@
                 $contextrole = &mt('Existing Roles in this Course');
             }
         } elsif ($env{'request.role'} =~ /^au\./) {
-            $contextrole = &mt('Existing Co-Author Roles in your Construction Space');
+            $contextrole = &mt('Existing Co-Author Roles in your Authoring Space');
         } else {
             $contextrole = &mt('Existing Roles in this Domain');
         }
@@ -1848,7 +1848,7 @@
 '</th><th>'.$lt{'rol'}.'</th><th>'.$lt{'ext'}.
 '</th><th>'.$lt{'sta'}.'</th><th>'.$lt{'end'}.'</th>'.
 &Apache::loncommon::end_data_table_header_row());
-        foreach my $type ('Construction Space','Course','Community','Domain','System','Unknown') {
+        foreach my $type ('Authoring Space','Course','Community','Domain','System','Unknown') {
             if ($output{$type}) {
                 $r->print($output{$type}."\n");
             }
@@ -1873,7 +1873,7 @@
         my $cuname=$env{'user.name'};
         my $cudom=$env{'request.role.domain'};
         my %lt=&Apache::lonlocal::texthash(
-                    'cs'   => "Construction Space",
+                    'cs'   => "Authoring Space",
                     'act'  => "Activate",
                     'rol'  => "Role",
                     'ext'  => "Extent",
@@ -1924,7 +1924,7 @@
                       '</span>');
         } elsif (($env{'user.name'} eq $ccuname) &&
              ($env{'user.domain'} eq $ccdomain)) {
-            $r->print(&mt('Assigning yourself a co-author or assistant co-author role in your own author area in Construction Space is not permitted'));
+            $r->print(&mt('Assigning yourself a co-author or assistant co-author role in your own author area in Authoring Space is not permitted'));
         }
     }
     return $addrolesdisplay;;
Index: loncom/interface/lonhtmlcommon.pm
diff -u loncom/interface/lonhtmlcommon.pm:1.345 loncom/interface/lonhtmlcommon.pm:1.346
--- loncom/interface/lonhtmlcommon.pm:1.345	Tue May 21 19:30:11 2013
+++ loncom/interface/lonhtmlcommon.pm	Tue Jun  4 23:12:08 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.345 2013/05/21 19:30:11 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.346 2013/06/04 23:12:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -3584,7 +3584,7 @@
 
 The actionlist is used to offer contextual actions, mostly at the bottom
 of a page, on which the outcome of an processed action is shown,
-e.g. a file operation in Construction Space.
+e.g. a file operation in Authoring Space.
 
 =over
 
Index: loncom/interface/lonprintout.pm
diff -u loncom/interface/lonprintout.pm:1.632 loncom/interface/lonprintout.pm:1.633
--- loncom/interface/lonprintout.pm:1.632	Sat Jun  1 00:22:37 2013
+++ loncom/interface/lonprintout.pm	Tue Jun  4 23:12:09 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Printout
 #
-# $Id: lonprintout.pm,v 1.632 2013/06/01 00:22:37 raeburn Exp $
+# $Id: lonprintout.pm,v 1.633 2013/06/04 23:12:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1105,7 +1105,7 @@
     # there is '\\ \\ ' in the page header. That's cause a error in LaTeX
     if($format =~ /\\\\\s\\\\\s/) {
         #TODO find sensible caption for page header
-        my $testPrintout = '\\\\'.&mt('Construction Space').' \\\\'.&mt('Test-Printout ');
+        my $testPrintout = '\\\\'.&mt('Authoring Space').' \\\\'.&mt('Test-Printout ');
         $format =~ s/\\\\\s\\\\\s/$testPrintout/;
     }
     #
@@ -2218,7 +2218,7 @@
 			$texversion.=&path_to_problem($urlp,$LaTeXwidth);
 		    } else {
 			$texversion.='\vskip 0 mm \noindent\textbf{'.
-                        &mt("Printing from Construction Space: No Title").'}\vskip 0 mm ';
+                        &mt("Printing from Authoring Space: No Title").'}\vskip 0 mm ';
 			$texversion.=&path_to_problem($urlp,$LaTeXwidth);
 		    }
 		    $texversion.='\vskip 1 mm '.$answer.'\end{document}';
@@ -2799,7 +2799,7 @@
 			$texversion.=&path_to_problem($cleanURL,$LaTeXwidth);
 		    } else {
 			$texversion.='\vskip 0 mm \noindent\textbf{'.
-                        &mt("Printing from Construction Space: No Title").'}\vskip 0 mm ';
+                        &mt("Printing from Authoring Space: No Title").'}\vskip 0 mm ';
 
 			$texversion.=&path_to_problem($cleanURL,$LaTeXwidth);
 		    }
@@ -3371,7 +3371,7 @@
 			    $texversion.=&path_to_problem ($urlp,$LaTeXwidth);
 			} else {
 			    $texversion.='\vskip 0 mm \noindent\textbf{'.
-                                         &mt("Printing from Construction Space: No Title").'}\vskip 0 mm ';
+                                         &mt("Printing from Authoring Space: No Title").'}\vskip 0 mm ';
 			    $texversion.=&path_to_problem ($urlp,$LaTeXwidth);
 			}
 			$texversion.='\vskip 1 mm '.$answer.'\end{document}';
Index: loncom/interface/lonsource.pm
diff -u loncom/interface/lonsource.pm:1.29 loncom/interface/lonsource.pm:1.30
--- loncom/interface/lonsource.pm:1.29	Mon Oct 29 17:38:56 2012
+++ loncom/interface/lonsource.pm	Tue Jun  4 23:12:09 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Source Code handler
 #
-# $Id: lonsource.pm,v 1.29 2012/10/29 17:38:56 raeburn Exp $
+# $Id: lonsource.pm,v 1.30 2013/06/04 23:12:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -52,7 +52,7 @@
 sub stage_2 {
     my ($r, $filename, $listname) = @_;
     my ($author)=($filename=~/\/res\/[^\/]+\/([^\/]+)\//);
-    $r->print(&Apache::loncommon::start_page('Copy Problem Source Code to Construction Space')
+    $r->print(&Apache::loncommon::start_page('Copy Problem Source Code to Authoring Space')
              .&mt('Please enter the directory that you would like the source code to go into.')
              .'<p>'
              .&mt('Note: the path is in reference to the root of your construction space,'
@@ -236,7 +236,7 @@
               <input type="hidden" name="filename" value="'.$filename.'" />
               <input type="hidden" name="listname" value="'.$listname.'" />
               <input type="hidden" name="action" value="stage2" />
-              <input type="submit" value="'.&mt('Copy to Construction Space').'" />
+              <input type="submit" value="'.&mt('Copy to Authoring Space').'" />
              </form><hr />
                 ');
             } else {
Index: loncom/interface/mydesk.tab
diff -u loncom/interface/mydesk.tab:1.160 loncom/interface/mydesk.tab:1.161
--- loncom/interface/mydesk.tab:1.160	Sat May 25 23:10:29 2013
+++ loncom/interface/mydesk.tab	Tue Jun  4 23:12:09 2013
@@ -90,7 +90,7 @@
 scnd:/public/[cdom]/[cnum]/syllabus:::Syllabus:showsyllabus
 scnd:/adm/[cdom]/[cnum]/_rss.html:::Feeds:showfeeds
 scnd:/adm/roles:::Roles:
-scnd:/priv/[udom]/[uname]/:::Construction Space:author
+scnd:/priv/[udom]/[uname]/:::Authoring Space:author
 scnd:/res/[udom]/[uname]/?launch=1:::Browse:author
 scnd:/adm/createuser:::People:cca
 
Index: loncom/interface/lonmeta.pm
diff -u loncom/interface/lonmeta.pm:1.250 loncom/interface/lonmeta.pm:1.251
--- loncom/interface/lonmeta.pm:1.250	Fri May  3 14:00:58 2013
+++ loncom/interface/lonmeta.pm	Tue Jun  4 23:12:08 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.250 2013/05/03 14:00:58 bisitz Exp $
+# $Id: lonmeta.pm,v 1.251 2013/06/04 23:12:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -778,7 +778,7 @@
 
     if ($env{'request.state'} eq 'construct') {
         &Apache::lonhtmlcommon::add_breadcrumb({
-            'text'  => 'Construction Space',
+            'text'  => 'Authoring Space',
             'href'  => &Apache::loncommon::authorspace($uri),
         });
     }
@@ -829,7 +829,7 @@
         $r->print(&pageheader());
         &present_editable_metadata($r,$uri,'groups');    
     } elsif ($uri=~m|^/priv|) { 
-        # Construction space
+        # Authoring space
         &Apache::lonhtmlcommon::add_breadcrumb({
             'text'  => 'Edit Metadata',
             'href'  => '',
@@ -1292,7 +1292,7 @@
 #####################################################
 sub present_editable_metadata {
     my ($r,$uri,$file_type) = @_;
     # Construction Space Call
     # Header
     my $disuri=$uri;
     my $fn=&Apache::lonnet::filelocation('',$uri);
@@ -1292,7 +1292,7 @@
 sub present_editable_metadata {
     my ($r,$uri,$file_type) = @_;
-    # Construction Space Call
+    # Authoring Space Call
     # Header
     my $disuri=$uri;
Index: loncom/auth/loncacc.pm
diff -u loncom/auth/loncacc.pm:1.60 loncom/auth/loncacc.pm:1.61
--- loncom/auth/loncacc.pm:1.60	Mon Oct 29 17:39:06 2012
+++ loncom/auth/loncacc.pm	Tue Jun  4 23:12:13 2013
@@ -1,8 +1,8 @@
 # The LearningOnline Network
 # Cookie Based Access Handler for Construction Area
 # (lonacc: 5/21/99,5/22,5/29,5/31 Gerd Kortemeyer)
 #
-# $Id: loncacc.pm,v 1.60 2012/10/29 17:39:06 raeburn Exp $
+# $Id: loncacc.pm,v 1.61 2013/06/04 23:12:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,7 +31,7 @@
 
 =head1 NAME
 
-Apache::lonacc - Cookie Based Access Handler for Construction Area
+Apache::lonacc - Cookie Based Access Handler for Authoring Spaces 
 
 =head1 SYNOPSIS
 
@@ -1,8 +1,8 @@
 # The LearningOnline Network
-# Cookie Based Access Handler for Construction Area
+# Cookie Based Access Handler for Authoring Spaces
 # (lonacc: 5/21/99,5/22,5/29,5/31 Gerd Kortemeyer)
 #


More information about the LON-CAPA-cvs mailing list